==> amarok-2.9.0.tar.xz: amarok-2.9.0/src/core-impl/collections/audiocd/support/AudioCdDeviceInfo.cpp <==
/****************************************************************************************
 * Copyright (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "AudioCdDeviceInfo.h"
#include "MediaDeviceInfo.h"

AudioCdDeviceInfo::AudioCdDeviceInfo( QString device, QString udi )
: MediaDeviceInfo(),
m_device( device )
{
    m_udi = udi;
}

AudioCdDeviceInfo::~AudioCdDeviceInfo()
{
}

QString
AudioCdDeviceInfo::device()
{
    return m_device;
}

#include "AudioCdDeviceInfo.moc"

==> amarok_3.2.2.orig.tar.xz: amarok-3.2.2/src/core-impl/collections/audiocd/support/AudioCdDeviceInfo.cpp <==
/****************************************************************************************
 * Copyright (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "AudioCdDeviceInfo.h"
#include "MediaDeviceInfo.h"

AudioCdDeviceInfo::AudioCdDeviceInfo( const QString &device, const QString &udi )
: MediaDeviceInfo(),
m_device( device )
{
    m_udi = udi;
}

AudioCdDeviceInfo::~AudioCdDeviceInfo()
{
}

QString
AudioCdDeviceInfo::device() const
{
    return m_device;
}
